Calculates the solar irradiance reflected from the Martian surface (ground-reflected radiation) incident on an inclined surface. Accounts for the view factor of the ground from the tilted surface.
G_ali(
Ls,
phi,
longitude,
Ts,
z = Z(Ls = Ls, Ts = Ts, phi = phi),
tau,
al = albedo(latitude = phi, longitude = longitude, tau = tau),
beta
)Albedo-reflected irradiance on inclined surface [W/m²]
Areocentric longitude [deg]
Planetary latitude [deg]
Planetary longitude [deg]
Solar time [h]
Sun zenith angle [deg]. If not provided, calculated from Ls, phi, and Ts
Atmospheric optical depth (dimensionless)
Surface albedo (dimensionless, 0-1). If not provided, calculated from latitude, longitude, and tau
Surface tilt/slope angle from horizontal [deg]