Calculates the direct beam solar irradiance on the Martian surface normal to the solar rays (i.e., perpendicular to the sun's direction). Uses Beer's law to account for atmospheric attenuation. Implements Equation 14 from Appelbaum & Flood (1990).
G_b(Ls, phi = NULL, Ts = NULL, z = Z(Ls = Ls, phi = phi, Ts = Ts), tau)Direct beam irradiance normal to sun [W/m²]
Areocentric longitude [deg]
Planetary latitude [deg]. Can be NULL if z is provided
Solar time [h]. Can be NULL if z is provided
Sun zenith angle [deg]. If not provided, calculated from Ls, phi, and Ts
Atmospheric optical depth (dimensionless)