Calculates the direct beam solar irradiance incident on a horizontal surface on Mars. Accounts for the angle of incidence on the horizontal plane. Implements Equation 18 from Appelbaum & Flood (1990).
G_bh(Ls, phi, Ts, z = Z(Ls = Ls, phi = phi, Ts = Ts), tau)Direct beam irradiance on horizontal surface [W/m²]
Areocentric longitude [deg]
Planetary latitude [deg]
Solar time [h]
Sun zenith angle [deg]. If not provided, calculated from Ls, phi, and Ts
Atmospheric optical depth (dimensionless)