Calculates the diffuse solar irradiance (scattered by atmospheric dust) incident on a horizontal surface on Mars. Computed as the difference between global and direct beam irradiance. Implements Equation 16 from Appelbaum & Flood (1990).
G_dh(
Ls,
phi,
longitude,
Ts = NULL,
z = Z(Ls = Ls, phi = phi, Ts = Ts),
tau,
al = albedo(latitude = phi, longitude = longitude, tau = tau)
)Diffuse irradiance on horizontal surface [W/m²]
Areocentric longitude [deg]
Planetary latitude [deg]
Planetary longitude [deg]
Solar time [h]. Can be NULL for daily calculations
Sun zenith angle [deg]. If not provided, calculated from Ls, phi, and Ts
Atmospheric optical depth (dimensionless)
Surface albedo (dimensionless, 0-1). If not provided, calculated from latitude, longitude, and tau