Calculates the total solar irradiance (direct beam + diffuse + albedo) incident on a horizontal surface on Mars. Implements Equation 17 from Appelbaum & Flood (1990).
G_h(
Ls,
phi,
longitude,
Ts = NULL,
z = Z(Ls = Ls, phi = phi, Ts = Ts),
tau,
al = albedo(latitude = phi, longitude = longitude, tau = tau)
)Global irradiance [W/m²]
Areocentric longitude [deg]
Planetary latitude [deg]
Planetary longitude [deg]
Solar time [h]
Sun zenith angle [deg]. If not provided, calculated from Ls, phi, and Ts
Atmospheric optical depth (dimensionless)
Surface albedo (dimensionless, 0-1). If not provided, calculated from latitude, longitude, and tau