Learn R Programming

marsrad (version 1.0.0)

G_obh: Beam irradiance on horizontal surface at top of Mars atmosphere

Description

Calculates the solar beam irradiance on a horizontal surface at the top of the Martian atmosphere (before atmospheric attenuation). Implements Equation 5 from Appelbaum & Flood (1990).

Usage

G_obh(Ls, phi = NULL, Ts = NULL, z = Z(Ls = Ls, phi = phi, Ts = Ts))

Value

Beam irradiance at top of atmosphere [W/m²]

Arguments

Ls

Areocentric longitude [deg]

phi

Planetary latitude [deg]. Can be NULL if z is provided

Ts

Solar time [h]. Can be NULL if z is provided

z

Sun zenith angle [deg]. If not provided, calculated from Ls, phi, and Ts