Calculates the diffuse solar energy (scattered by atmospheric dust) received on a horizontal surface between specified start and end times. Computed as difference between global and beam insolation.
I_dh(
Ls,
phi,
longitude,
tau,
Ts_start,
Ts_end,
al = albedo(latitude = phi, longitude = longitude, tau = tau)
)Diffuse insolation over specified time period [Wh/m²]
Areocentric longitude [deg]
Planetary latitude [deg]
Planetary longitude [deg]
Atmospheric optical depth (dimensionless)
Start of integration period [h]
End of integration period [h]
Surface albedo (dimensionless, 0-1). If not provided, calculated from latitude, longitude, and tau