Learn R Programming

marsrad (version 1.0.0)

df_albedo: Albedo lookup table

Description

Lookup table for Mars surface albedo based on latitude and longitude. Based on NASA Technical Memorandum data.

Usage

df_albedo

Arguments

Format

A data frame with albedo values indexed by latitude and longitude