powered by
Lookup table for normalized net flux function with albedo 0.4. From NASA TM-103623 (Appelbaum & Flood, 1990).
df_netflux_0p4_lookup_v2
A data frame with net flux values indexed by zenith angle and optical depth