Learn R Programming

marsrad (version 1.0.0)

is_polar_day: Check if location is experiencing polar day

Description

Determines whether a given location on Mars is experiencing polar day (24-hour sunlight) for the specified season. During polar day, the sun remains above the horizon continuously.

Usage

is_polar_day(Ls, phi)

Value

TRUE if experiencing polar day, FALSE otherwise

Arguments

Ls

Areocentric longitude [deg]

phi

Planetary latitude [deg]