Calculates the direct beam solar irradiance incident on an inclined surface on Mars. Accounts for the sun's angle of incidence on the tilted and oriented surface. Based on Appelbaum, Flood & Norambuena (1994).
G_bi(Ls, phi, Ts, z = Z(Ls = Ls, phi = phi, Ts = Ts), tau, beta, gamma_c)Direct beam irradiance on inclined surface [W/m²]
Areocentric longitude [deg]
Planetary latitude [deg]
Solar time [h]
Sun zenith angle [deg]. If not provided, calculated from Ls, phi, and Ts
Atmospheric optical depth (dimensionless)
Surface tilt/slope angle from horizontal [deg]
Surface azimuth angle [deg]. Zero facing equator, east negative, west positive (-180 to +180)