Calculates the diffuse solar irradiance (scattered by atmospheric dust) incident on an inclined surface on Mars. Accounts for the view factor of the sky from the tilted surface.
G_di(
Ls,
phi,
longitude,
Ts,
z = Z(Ls = Ls, phi = phi, Ts = Ts),
tau,
al = albedo(latitude = phi, longitude = longitude, tau = tau),
beta
)Diffuse irradiance on inclined surface [W/m²]
Areocentric longitude [deg]
Planetary latitude [deg]
Planetary longitude [deg]
Solar time [h]
Sun zenith angle [deg]. If not provided, calculated from Ls, phi, and Ts
Atmospheric optical depth (dimensionless)
Surface albedo (dimensionless, 0-1). If not provided, calculated from latitude, longitude, and tau
Surface tilt/slope angle from horizontal [deg]