Calculates the total solar irradiance (direct beam + diffuse + albedo-reflected) incident on an inclined surface on Mars. Implements Equation 3 from Appelbaum, Flood & Norambuena (1994).
G_i(
Ls,
phi,
longitude,
Ts,
z = Z(Ls = Ls, phi = phi, Ts = Ts),
tau,
al = albedo(latitude = phi, longitude = longitude, tau = tau),
beta,
gamma_c
)Global irradiance on inclined surface [W/m²]
Areocentric longitude [deg]
Planetary latitude [deg]
Planetary longitude [deg]
Solar time [h]
Sun zenith angle [deg]. If not provided, calculated from Ls, phi, and Ts
Atmospheric optical depth (dimensionless)
Surface albedo (dimensionless, 0-1). If not provided, calculated from latitude, longitude, and tau
Surface tilt/slope angle from horizontal [deg]
Surface azimuth angle [deg]. Zero facing equator, east negative, west positive (-180 to +180)