Calculates the solar beam irradiance on a horizontal surface at the top of the Martian atmosphere (before atmospheric attenuation). Implements Equation 5 from Appelbaum & Flood (1990).
G_obh(Ls, phi = NULL, Ts = NULL, z = Z(Ls = Ls, phi = phi, Ts = Ts))Beam irradiance at top of atmosphere [W/m²]
Areocentric longitude [deg]
Planetary latitude [deg]. Can be NULL if z is provided
Solar time [h]. Can be NULL if z is provided
Sun zenith angle [deg]. If not provided, calculated from Ls, phi, and Ts