Calculates the total solar energy received on an inclined surface between specified start and end times. Obtained by integrating global irradiance over the time period.
I_i(
Ls,
phi,
longitude,
tau,
Ts_start,
Ts_end,
al = albedo(latitude = phi, longitude = longitude, tau = tau),
beta,
gamma_c
)Global insolation on inclined surface over specified time period [Wh/m²]
Areocentric longitude [deg]
Planetary latitude [deg]
Planetary longitude [deg]
Atmospheric optical depth (dimensionless)
Start of integration period [h]
End of integration period [h]
Surface albedo (dimensionless, 0-1). If not provided, calculated from latitude, longitude, and tau
Surface tilt/slope angle from horizontal [deg]
Surface azimuth angle [deg]. Zero facing equator, east negative, west positive (-180 to +180)